# Spinny

Ever wanted a simple solution to a simple problem? I've attempted to do that with a *very* simple
spinner library. It's so small, that you don't even need to install it; you can just copy and paste
it into your code file. Yes, I said *file*, not *base*. Why? It's about 10 lines long. And it
uses only vanilla Python. It's based off of [this Stackoverflow answer](https://stackoverflow.com/a/39504463). It can
be installed from PyPI [here](https://pypi.org/project/spinny/). 

Jut saying, the code is golfed so that it's as short as I can make it. Although that makes it copy-and-pastable,
it also makes it illegible. *Caveat emptor*.

## How to use it

See the example below (there's an error, you should import it using the phrase ``spinny``):

![Spinner Example](example.gif)

It also handles errors cleanly, printing out the cause of the error and stopping.
